@@ -22,7 +22,7 @@
 #ifndef _mydumper_h
 #define _mydumper_h
 
-enum job_type { JOB_SHUTDOWN, JOB_RESTORE, JOB_DUMP, JOB_DUMP_NON_INNODB, JOB_SCHEMA, JOB_BINLOG, JOB_LOCK_DUMP_NON_INNODB };
+enum job_type { JOB_SHUTDOWN, JOB_RESTORE, JOB_DUMP, JOB_DUMP_NON_INNODB, JOB_SCHEMA, JOB_VIEW, JOB_TRIGGERS, JOB_SCHEMA_POST, JOB_BINLOG, JOB_LOCK_DUMP_NON_INNODB };
 
 struct configuration {
 	char use_any_index;
@@ -63,6 +63,18 @@ struct schema_job {
 	char *filename;
 };
 
+struct view_job {
+	char *database;
+	char *table;
+	char *filename;
+	char *filename2;
+};
+
+struct schema_post_job {
+	char *database;
+	char *filename;
+};
+
 struct restore_job {
 	char *database;
 	char *table;
@@ -81,6 +93,8 @@ struct db_table {
 	guint64 datalength;
 };
 
-
+struct schema_post {
+	char* database;
+};
 
 #endif
